@@ -1,4 +1,4 @@
-/* $Id: acconfig.h,v 1.8 2000/12/01 18:46:01 astyanax Exp $ */
+/* $Id: acconfig.h,v 1.9 2000/12/06 01:08:10 astyanax Exp $ */
 
 /* Define this if you have the wresize function in your ncurses-type library */
 #undef HAVE_WRESIZE
@@ -34,6 +34,6 @@
 #undef DISABLE_JUSTIFY
 
 /* Define this to disable the use(full|less) spelling functions */
-#undef DISABLE_SPELL
+#undef DISABLE_SPELLER
 
 
