@@ -1,4 +1,4 @@
-/* $Id: proto.h,v 1.24 2000/11/14 18:25:26 astyanax Exp $ */
+/* $Id: proto.h,v 1.29 2000/11/29 04:33:26 astyanax Exp $ */
 /**************************************************************************
  *   proto.h                                                              *
  *                                                                        *
@@ -88,9 +88,11 @@ int do_down(void);
 int do_left(void);
 int do_right(void);
 int check_wildcard_match(const char *text, const char *pattern);
-char *input_tab(char *buf, int place, int *lastWasTab, int *newplace);
 
-void shortcut_init(void);
+char *input_tab(char *buf, int place, int *lastWasTab, int *newplace);
+char *real_dir_from_tilde(char *buf);
+
+void shortcut_init(int unjustify);
 void lowercase(char *src);
 void blank_bottombars(void);
 void check_wrap(filestruct * inptr, char ch);
@@ -129,6 +131,11 @@ void page_up_center(void);
 void blank_edit(void);
 void search_init_globals(void);
 void replace_abort(void);
+void add_to_cutbuffer(filestruct * inptr);
+void do_replace_highlight(int highlight_flag, char *word);
+#ifdef NANO_EXTRA
+void do_credits(void);
+#endif
 
 int do_writeout_void(void), do_exit(void), do_gotoline_void(void);
 int do_insertfile(void), do_search(void), page_up(void), page_down(void);
